==> plantuml-libs-5.2.0.tgz: package/distribution/azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioClassicWebServices.md <==
# ServiceMachineLearningStudioClassicWebServices


```text
azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioClassicWebServices
```

```text
include('azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioClassicWebServices')
```



| Illustration | ServiceMachineLearningStudioClassicWebServices | ServiceMachineLearningStudioClassicWebServicesCard | ServiceMachineLearningStudioClassicWebServicesGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioClassicWebServices.png) | ![illustration for ServiceMachineLearningStudioClassicWebServices](../../../azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioClassicWebServices.Local.png) | ![illustration for ServiceMachineLearningStudioClassicWebServicesCard](../../../azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioClassicWebServicesCard.Local.png) | ![illustration for ServiceMachineLearningStudioClassicWebServicesGroup](../../../azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioClassicWebServicesGroup.Local.png) |




## ServiceMachineLearningStudioClassicWebServices

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceMachineLearningStudioClassicWebServices
include('azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioClassicWebServices')

' renders the element
ServiceMachineLearningStudioClassicWebServices('ServiceMachineLearningStudioClassicWebServices', 'Service Machine Learning Studio Classic Web Services', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceMachineLearningStudioClassicWebServices
include('azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioClassicWebServices')

' renders the element
ServiceMachineLearningStudioClassicWebServices('ServiceMachineLearningStudioClassicWebServices', 'Service Machine Learning Studio Classic Web Services', 'an optional tech label')
@enduml
```

## ServiceMachineLearningStudioClassicWebServicesCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceMachineLearningStudioClassicWebServicesCard
include('azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioClassicWebServices')

' renders the element
ServiceMachineLearningStudioClassicWebServicesCard('ServiceMachineLearningStudioClassicWebServicesCard', 'Service Machine Learning Studio Classic Web Services Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceMachineLearningStudioClassicWebServicesCard
include('azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioClassicWebServices')

' renders the element
ServiceMachineLearningStudioClassicWebServicesCard('ServiceMachineLearningStudioClassicWebServicesCard', 'Service Machine Learning Studio Classic Web Services Card', 'an optional description')
@enduml
```

## ServiceMachineLearningStudioClassicWebServicesGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceMachineLearningStudioClassicWebServicesGroup
include('azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioClassicWebServices')

' renders the element
ServiceMachineLearningStudioClassicWebServicesGroup('ServiceMachineLearningStudioClassicWebServicesGroup', 'Service Machine Learning Studio Classic Web Services Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceMachineLearningStudioClassicWebServicesGroup
include('azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioClassicWebServices')

' renders the element
ServiceMachineLearningStudioClassicWebServicesGroup('ServiceMachineLearningStudioClassicWebServicesGroup', 'Service Machine Learning Studio Classic Web Services Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioClassicWebServices.md <==
# ServiceMachineLearningStudioClassicWebServices


```text
azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioClassicWebServices
```

```text
include('azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioClassicWebServices')
```



| Illustration | ServiceMachineLearningStudioClassicWebServices | ServiceMachineLearningStudioClassicWebServicesCard | ServiceMachineLearningStudioClassicWebServicesGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioClassicWebServices.png) | ![illustration for ServiceMachineLearningStudioClassicWebServices](../../../azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioClassicWebServices.Local.png) | ![illustration for ServiceMachineLearningStudioClassicWebServicesCard](../../../azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioClassicWebServicesCard.Local.png) | ![illustration for ServiceMachineLearningStudioClassicWebServicesGroup](../../../azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioClassicWebServicesGroup.Local.png) |




## ServiceMachineLearningStudioClassicWebServices

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceMachineLearningStudioClassicWebServices
include('azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioClassicWebServices')

' renders the element
ServiceMachineLearningStudioClassicWebServices('ServiceMachineLearningStudioClassicWebServices', 'Service Machine Learning Studio Classic Web Services', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceMachineLearningStudioClassicWebServices
include('azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioClassicWebServices')

' renders the element
ServiceMachineLearningStudioClassicWebServices('ServiceMachineLearningStudioClassicWebServices', 'Service Machine Learning Studio Classic Web Services', 'an optional tech label')
@enduml
```

## ServiceMachineLearningStudioClassicWebServicesCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceMachineLearningStudioClassicWebServicesCard
include('azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioClassicWebServices')

' renders the element
ServiceMachineLearningStudioClassicWebServicesCard('ServiceMachineLearningStudioClassicWebServicesCard', 'Service Machine Learning Studio Classic Web Services Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceMachineLearningStudioClassicWebServicesCard
include('azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioClassicWebServices')

' renders the element
ServiceMachineLearningStudioClassicWebServicesCard('ServiceMachineLearningStudioClassicWebServicesCard', 'Service Machine Learning Studio Classic Web Services Card', 'an optional description')
@enduml
```

## ServiceMachineLearningStudioClassicWebServicesGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceMachineLearningStudioClassicWebServicesGroup
include('azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioClassicWebServices')

' renders the element
ServiceMachineLearningStudioClassicWebServicesGroup('ServiceMachineLearningStudioClassicWebServicesGroup', 'Service Machine Learning Studio Classic Web Services Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceMachineLearningStudioClassicWebServicesGroup
include('azure-4/Item/AiMachineLearning/ServiceMachineLearningStudioClassicWebServices')

' renders the element
ServiceMachineLearningStudioClassicWebServicesGroup('ServiceMachineLearningStudioClassicWebServicesGroup', 'Service Machine Learning Studio Classic Web Services Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
